@@ -215,22 +215,6 @@ UT_Error IE_Exp_OpenXML::finishDocument()
 	return UT_OK;
 }
 
-/**
- * Starts exporting the OXML_Section object
- */
-UT_Error IE_Exp_OpenXML::startSection()
-{
-	return writeTargetStream(TARGET_DOCUMENT, "<wx:sect>");
-}
-
-/**
- * Finishes exporting the OXML_Section object
- */
-UT_Error IE_Exp_OpenXML::finishSection()
-{
-	return writeTargetStream(TARGET_DOCUMENT, "</wx:sect>");
-}
-
 /**
  * Starts exporting the OXML_Section object's properties
  */
@@ -850,6 +834,8 @@ UT_Error IE_Exp_OpenXML::setFontFamily(int target, const gchar* family)
 	str += sEscFamily.utf8_str();
 	str += "\" w:cs=\"";
 	str += sEscFamily.utf8_str();
+	str += "\" w:hAnsi=\"";
+	str += sEscFamily.utf8_str();
 	str += "\"/>";
 	return writeTargetStream(target, str.c_str());
 }
@@ -1177,11 +1163,11 @@ UT_Error IE_Exp_OpenXML::setTabstops(int target, const gchar* tabstops)
 				tabs += "<w:tab w:val=\"clear\" ";
 
 
-			if(strstr(type.c_str(), "1"))
+			if(strstr(type.c_str(), "3"))
 				tabs += "w:leader=\"underscore\" ";
-			else if(strstr(type.c_str(), "2"))
+			else if(strstr(type.c_str(), "1"))
 				tabs += "w:leader=\"dot\" ";
-			else if(strstr(type.c_str(), "3"))
+			else if(strstr(type.c_str(), "2"))
 				tabs += "w:leader=\"hyphen\" ";
 		
 			tabs += "w:pos=\"";
@@ -1247,7 +1233,7 @@ UT_Error IE_Exp_OpenXML::setGridSpan(int target, UT_sint32 hspan)
  */
 UT_Error IE_Exp_OpenXML::setVerticalMerge(int target, const char* vmerge)
 {
-	std::string str("<w:vmerge w:val=\"");
+	std::string str("<w:vMerge w:val=\"");
 	str += vmerge;
 	str += "\"/>";
 	return writeTargetStream(target, str.c_str());
@@ -1263,6 +1249,50 @@ UT_Error IE_Exp_OpenXML::setPageBreak(int target)
 	return writeTargetStream(target, str.c_str());
 }
 
+/**
+ * Sets page size and orientation
+ */
+UT_Error IE_Exp_OpenXML::setPageSize(int target, const char* width, const char* height, const char* orientation)
+{
+	std::string str("<w:pgSz w:w=\"");
+	str += width;
+	str += "\"";
+
+	str += " w:h=\"";
+	str += height;
+	str += "\"";
+
+	str += " w:orient=\"";
+	str += orientation;
+	str += "\"/>";
+
+	return writeTargetStream(target, str.c_str());	
+}
+
+/**
+ * Sets page margins
+ */
+UT_Error IE_Exp_OpenXML::setPageMargins(int target, const char* top, const char* left, const char* right, const char* bottom)
+{
+	std::string str("<w:pgMar w:top=\"");
+	str += convertToTwips(top);
+	str += "\"";
+
+	str += " w:left=\"";
+	str += convertToTwips(left);
+	str += "\"";
+
+	str += " w:right=\"";
+	str += convertToTwips(right);
+	str += "\"";
+
+	str += " w:bottom=\"";
+	str += convertToTwips(bottom);
+	str += "\"/>";
+
+	return writeTargetStream(target, str.c_str());	
+}
+
 /**
  * Sets table border style for the specified border in the table
  */
@@ -1294,6 +1324,18 @@ UT_Error IE_Exp_OpenXML::setTableBorder(int target, const char* border, const ch
 	return writeTargetStream(target, str.c_str());
 }
 
+/**
+ * Sets table row height to some exact value
+ */
+UT_Error IE_Exp_OpenXML::setRowHeight(int target, const char* height)
+{
+	std::string str("<w:trHeight w:val=\"");
+	str += convertToPositiveTwips(height);
+	str += "\" w:hRule=\"exact\"/>";
+	return writeTargetStream(target, str.c_str());
+}
+
+
 /**
  * Starts table grid
  */
@@ -1310,6 +1352,22 @@ UT_Error IE_Exp_OpenXML::finishTableGrid(int target)
 	return writeTargetStream(target, "</w:tblGrid>");
 }
 
+/**
+ * Starts table row properties
+ */
+UT_Error IE_Exp_OpenXML::startRowProperties(int target)
+{
+	return writeTargetStream(target, "<w:trPr>");
+}
+
+/**
+ * Finishes table row properties
+ */
+UT_Error IE_Exp_OpenXML::finishRowProperties(int target)
+{
+	return writeTargetStream(target, "</w:trPr>");
+}
+
 /**
  * Starts footnote
  */
@@ -1435,7 +1493,8 @@ UT_Error IE_Exp_OpenXML::setListStartValue(int target, UT_uint32 startValue)
 UT_Error IE_Exp_OpenXML::setListLevelText(int target, const char* text)
 {
 	UT_UTF8String sEscText = text;
-	sEscText.escapeXML();
+	if(!isListBullet(text))
+		sEscText.escapeXML();
 
 	std::string str("<w:lvlText w:val=\"");
 	str += sEscText.utf8_str();
@@ -1443,6 +1502,15 @@ UT_Error IE_Exp_OpenXML::setListLevelText(int target, const char* text)
 	return writeTargetStream(target, str.c_str());
 }
 
+/**
+ * Checks whether given a string is a special list bullet symbol
+ */
+bool IE_Exp_OpenXML::isListBullet(const char* str)
+{
+	return !strcmp(str, BULLET) || !strcmp(str, SQUARE) || !strcmp(str, TRIANGLE) || !strcmp(str, TICK) || !strcmp(str, IMPLIES) || 
+			!strcmp(str, DIAMOND) || !strcmp(str, BOX) || !strcmp(str, HAND) || !strcmp(str, HEART) || !strcmp(str, DASH);
+}
+
 /**
  * Sets abstract numbering id
  */
@@ -1562,7 +1630,7 @@ UT_Error IE_Exp_OpenXML::setImageRelation(const char* filename, const char* id)
 /**
  * Sets the simple field
  */
-UT_Error IE_Exp_OpenXML::setSimpleField(const char* instr, const char* value)
+UT_Error IE_Exp_OpenXML::setSimpleField(int target, const char* instr, const char* value)
 {
 	UT_UTF8String sEscInstr = instr;
 	sEscInstr.escapeXML();
@@ -1579,7 +1647,7 @@ UT_Error IE_Exp_OpenXML::setSimpleField(const char* instr, const char* value)
 	str += "</w:t>";
 	str += "</w:r>";
 	str += "</w:fldSimple>";
-	return writeTargetStream(TARGET_DOCUMENT, str.c_str());
+	return writeTargetStream(target, str.c_str());
 }
 
 /**
@@ -1729,7 +1797,7 @@ const gchar * IE_Exp_OpenXML::convertToLines(const gchar* str)
 const gchar * IE_Exp_OpenXML::computeBorderWidth(const gchar* str)
 {
 	//in eighths of a point
-	double pt = UT_convertDimensionless(str) * 160;
+	double pt = UT_convertToPoints(str) * 8;
 	if(pt < 1.0 && pt > -1.0)
 		return "0";
 	return UT_convertToDimensionlessString(pt, ".0");
@@ -1984,6 +2052,10 @@ UT_Error IE_Exp_OpenXML::startContentTypes()
 	str += "<Default Extension=\"rels\" ContentType=\"application/vnd.openxmlformats-package.relationships+xml\"/>";
 	str += "<Default Extension=\"xml\" ContentType=\"application/xml\"/>";
 	str += "<Default Extension=\"png\" ContentType=\"image/png\"/>";
+	str += "<Default Extension=\"jpg\" ContentType=\"image/jpeg\"/>";
+	str += "<Default Extension=\"jpeg\" ContentType=\"image/jpeg\"/>";
+	str += "<Default Extension=\"gif\" ContentType=\"image/gif\"/>";
+	str += "<Default Extension=\"tiff\" ContentType=\"image/tiff\"/>";
 	str += "<Default Extension=\"svg\" ContentType=\"image/svg+xml\"/>";
 	str += "<Override PartName=\"/word/document.xml\" ";
 	str += "ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml\"/>";
@@ -2280,7 +2352,7 @@ UT_Error IE_Exp_OpenXML::startMainPart()
 		return err;
 	}	
 
-	std::string str("<w:wordDocument xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" ");
+	std::string str("<w:document xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" ");
 	str += "xmlns:v=\"urn:schemas-microsoft-com:vml\" ";
 	str += "xmlns:wx=\"http://schemas.microsoft.com/office/word/2003/auxHint\" ";
 	str += "xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\" ";
@@ -2298,7 +2370,7 @@ UT_Error IE_Exp_OpenXML::finishMainPart()
 {
 	UT_Error err = UT_OK;
 
-	err = writeTargetStream(TARGET_DOCUMENT, "</w:body></w:wordDocument>");
+	err = writeTargetStream(TARGET_DOCUMENT, "</w:body></w:document>");
 	if(err != UT_OK)
 	{
 		UT_DEBUGMSG(("FRT: ERROR, cannot write to document.xml file\n"));	
