@@ -32,7 +32,7 @@
 #include "xap_CocoaDlg_FontChooser.h"
 #include "xap_CocoaApp.h"
 #include "xap_EncodingManager.h"
-#include "gr_CocoaGraphics.h"
+#include "gr_CocoaCairoGraphics.h"
 
 // your typographer's standard nonsense latin font phrase
 #define PREVIEW_ENTRY_DEFAULT_STRING	"Lorem ipsum dolor sit amet, consectetaur adipisicing..."
@@ -255,7 +255,7 @@ void XAP_CocoaDialog_FontChooser::runModal(XAP_Frame * /*pFrame*/)
 		UT_RGBColor c;
 		UT_parseColor(sColor.c_str(), c);
 
-		NSColor *color = GR_CocoaGraphics::_utRGBColorToNSColor(c);
+		NSColor *color = GR_CocoaCairoGraphics::_utRGBColorToNSColor(c);
 		[m_dlg setTextColor:color];
 	}
 	else {
@@ -269,7 +269,7 @@ void XAP_CocoaDialog_FontChooser::runModal(XAP_Frame * /*pFrame*/)
 		UT_RGBColor c;
 		UT_parseColor(sBGCol.c_str(), c);
 
-		NSColor *color = GR_CocoaGraphics::_utRGBColorToNSColor(c);
+		NSColor *color = GR_CocoaCairoGraphics::_utRGBColorToNSColor(c);
 		[m_dlg setBgColor:color];
 	}
 	else
@@ -357,8 +357,8 @@ void XAP_CocoaDialog_FontChooser::_cancelAction(void)
 void	XAP_CocoaDialog_FontChooser::_createGC(XAP_CocoaNSView* owner)
 {
 	NSSize  size;
-	GR_CocoaAllocInfo ai(owner);
-	m_pGraphics = static_cast<GR_CocoaGraphics*>(XAP_App::getApp()->newGraphics(ai));
+	GR_CocoaCairoAllocInfo ai(owner);
+	m_pGraphics = static_cast<GR_CocoaCairoGraphics*>(XAP_App::getApp()->newGraphics(ai));
 
 	size = [owner bounds].size;
 	_createFontPreviewFromGC(m_pGraphics, lrintf(size.width), lrintf(size.height));
