@@ -46,6 +46,8 @@
 #include "ie_imp.h"
 #include "ie_impGraphic.h"
 
+#include "fg_Graphic.h"
+
 #include "xap_Win32Resources.rc2"
 
 
@@ -98,7 +100,12 @@ char * XAP_Win32Dialog_FileOpenSaveAs::_getDefaultExtension(UT_uint32 indx)
 	
 	UT_uint32 end = g_strv_length((gchar **) m_szDescriptions);
 	if(indx >= end)
+	{
+		if(m_id == XAP_DIALOG_ID_FILE_SAVE_IMAGE)
+			return "png";
+
 		return abw_sfx;
+	}
 	
 	// copy at most DEFAULT_EXT_SIZE characters from the suffix;
 	strncpy(m_szDefaultExtension, m_szSuffixes[indx] + 2, DEFAULT_EXT_SIZE);
@@ -363,6 +370,7 @@ void XAP_Win32Dialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		break;
 
 	case XAP_DIALOG_ID_FILE_SAVEAS:
+	case XAP_DIALOG_ID_FILE_SAVE_IMAGE:
 		ofn.lpstrTitle = pSS->getValue(XAP_STRING_ID_DLG_FOSA_SaveAsTitle);
 		ofn.lpfnHook	   = (LPOFNHOOKPROC) s_hookSaveAsProc;
 		ofn.Flags |= OFN_OVERWRITEPROMPT;
@@ -427,31 +435,31 @@ void XAP_Win32Dialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		UT_uint32 end = g_strv_length((gchar **) m_szSuffixes);
 
 		if ((m_id == XAP_DIALOG_ID_FILE_SAVEAS) &&
-			(!UT_pathSuffix(szFile)))
+			(UT_pathSuffix(szFile).empty()))
 		{
 			// add suffix based on selected file type
 			// if selected file is "all documents" or "all"
 			// default to .abw, since that is how it will get saved
 			UT_ASSERT(ofn.nFilterIndex > 0);
 
-			const char * szSuffix = NULL;
+			std::string suffix;
 			char abw_sfx[] = ".abw";
 			
 			if(ofn.nFilterIndex <= end)
-				szSuffix = UT_pathSuffix(m_szSuffixes[ofn.nFilterIndex - 1]);
+				suffix = UT_pathSuffix(m_szSuffixes[ofn.nFilterIndex - 1]);
 			else
-				szSuffix = abw_sfx;
+				suffix = abw_sfx;
 			
-			UT_ASSERT(szSuffix);
+			UT_ASSERT(!suffix.empty());
 
-			UT_uint32 length = strlen(szFile) + strlen(szSuffix) + 1;
+			UT_uint32 length = strlen(szFile) + suffix.size() + 1;
 			m_szFinalPathname = (char *)UT_calloc(length,sizeof(char));
 			if (m_szFinalPathname)
 			{
 				char * p = m_szFinalPathname;
 
 				strcpy(p,szFile);
-				strcat(p,szSuffix);
+				strcat(p,suffix.c_str());
 			}
 		}
 		else
@@ -665,46 +673,15 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 
 	UT_DEBUGMSG(("File Selected is %s\n", buf));
 
-	// Load File into memory
-	UT_ByteBuf* pBB 	= new UT_ByteBuf(NULL);
-	UT_ByteBuf* pTempBB = new UT_ByteBuf(NULL);
-	pBB->insertFromFile(0, buf);
-
 	// Build an Import Graphic based on file type
-	IEGraphicFileType iegft = IEGFT_Unknown;
-	IE_ImpGraphic* pIEG;
 	UT_Error errorCode = UT_ERROR;
-	char *uri = UT_go_filename_to_uri(buf);
-	if(uri)
-		errorCode = IE_ImpGraphic::constructImporter(uri, iegft, &pIEG);
+    FG_Graphic *pfg = NULL;
 
+    errorCode = IE_ImpGraphic::loadGraphic(buf, IEGFT_Unknown, &pfg);
 	if (errorCode)
 	{
-		DELETEP(pBB);
-		DELETEP(pTempBB);
 		return false;
 	}
-	iegft = pIEG->fileTypeForContents( (const char *) pBB->getPointer(0), 50);
-
-	// Skip import if PNG or SVG file
-	if (iegft != IEGFT_PNG && iegft != IEGFT_SVG)
-	{
-		// Convert to PNG or SVG (pBB Memoried freed in function
-		errorCode = pIEG->convertGraphic(pBB, &pTempBB);  
-		pBB = pTempBB;
-		if (errorCode)
-		{
-			DELETEP(pIEG);
-			DELETEP(pBB);
-			DELETEP(pTempBB);
-			FREEP(uri);
-			return false;
-		}
-	}
-	// Reset file type based on conversion
-	iegft = pIEG->fileTypeForContents( (const char *) pBB->getPointer(0), 50);
-	DELETEP(pIEG);
-	FREEP(uri);
 
 	double		scale_factor = 0.0;
 	UT_sint32	scaled_width,scaled_height;
@@ -714,19 +691,8 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 	GetClientRect (hThumbnail, &r);
 	InvalidateRect(hThumbnail, &r, true);
 
-	if (iegft == IEGFT_PNG)
-	{
-		UT_PNG_getDimensions(pBB, iImageWidth, iImageHeight);
-	}
-	else
-	{
-	//	TODO Fix this
-	//	UT_sint32 layoutWidth;
-	//	UT_sint32 layoutHeight;
-	//	UT_SVG_getDimensions(pBB, pGr, iImageWidth, iImageHeight, layoutWidth, layoutHeight);
-		iImageWidth = 0;
-		iImageHeight = 0;
-	}
+    iImageWidth = pfg->getWidth();
+    iImageHeight = pfg->getHeight();
 
 	// Update Height and Width Strings
 	sprintf( buf, 
@@ -756,7 +722,7 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 	scaled_height = (int) (scale_factor * iImageHeight);
 
 	GR_Win32Image* pImage = new GR_Win32Image(NULL);
-	pImage->convertFromBuffer(pBB, scaled_width, scaled_height);
+	pImage->convertFromBuffer(pfg->getBuffer(), pfg->getMimeType(), scaled_width, scaled_height);
 
 	PAINTSTRUCT ps;
 	HDC hdc = BeginPaint(hThumbnail, &ps);
@@ -771,7 +737,7 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 				   pGr->tlu((r.bottom - scaled_height) / 2));
 	EndPaint(hThumbnail,&ps);
 
-	DELETEP(pBB);
+    DELETEP(pfg);
 	DELETEP(pImage);
 	DELETEP(pGr);
 
